"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const postcss_1 = __importDefault(require("postcss"));
const index_1 = __importDefault(require("./index"));
function run(input, output, opts = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        let result = yield (0, postcss_1.default)([(0, index_1.default)(opts)]).process(input, { from: undefined });
        expect(result.css).toEqual(output);
        expect(result.warnings()).toHaveLength(0);
    });
}
it("handles prehyphened", () => __awaiter(void 0, void 0, void 0, function* () {
    const config = {
        "--dark": "prefers-color-scheme: dark",
    };
    yield run("", "@custom-media --dark (prefers-color-scheme: dark)", config);
}));
it("handles unhyphenated", () => __awaiter(void 0, void 0, void 0, function* () {
    const config = {
        dark: "prefers-color-scheme: dark",
    };
    yield run("", "@custom-media --dark (prefers-color-scheme: dark)", config);
}));
it("handles number values as mobile-first", () => __awaiter(void 0, void 0, void 0, function* () {
    const config = {
        sm: 600,
        md: 800,
        lg: 1000,
    };
    yield run("", `@custom-media --sm-only (600px <= width < 800px);
@custom-media --sm (600px <= width);
@custom-media --md-only (800px <= width < 1000px);
@custom-media --md (800px <= width);
@custom-media --lg (1000px <= width)`, config);
}));
it("handles number and string values", () => __awaiter(void 0, void 0, void 0, function* () {
    const config = {
        "--dark": "prefers-color-scheme: dark",
        sm: 600,
        md: 800,
    };
    yield run("a { color: red; }", `@custom-media --dark (prefers-color-scheme: dark);
@custom-media --sm-only (600px <= width < 800px);
@custom-media --sm (600px <= width);
@custom-media --md (800px <= width);
a { color: red; }`, config);
}));
//# sourceMappingURL=index.spec.js.map